pub trait AsLog: Sealed {
type Log;
// Required method
fn as_log(&self) -> Self::Log;
}Expand description
Trait implemented for tracing types that can be converted to a log
equivalent.
🛈 Note: This is pre-release documentation
for the upcoming tracing 0.2.0 ecosystem.
For the release documentation, please see docs.rs, instead.
pub trait AsLog: Sealed {
type Log;
// Required method
fn as_log(&self) -> Self::Log;
}Trait implemented for tracing types that can be converted to a log
equivalent.